==> artesian-sdk-3.0.0.dev1.tar.gz: artesian-sdk-3.0.0.dev1/Artesian/Query/_QueryParameters/MasQueryParameters.py <==
from typing import List
from .ExtractionRangeConfig import ExtractionRangeConfig
from .QueryParameters import _QueryParameters
from .ExtractionRangeType import ExtractionRangeType

class MasQueryParameters(_QueryParameters): 
    """ 
        Class for the Mas Query Parameters.

        Attributes:
            ids: sets list of marketdata ID's to be queried
            extractionRangeConfig: Sets the extraction range configuration.
            extraxtionRangeType: Sets the extraction range type.
            timezone: specifies the timezone of extracted marketdata.
            filterId: filters marketdata ID to be queries.
            products: sets products to be queried.
    """
    def __init__(self, ids: List[int] = None, 
                       extractionRangeConfig: ExtractionRangeConfig = ExtractionRangeConfig(), 
                       extractionRangeType: ExtractionRangeType = None, 
                       timezone: str = None, 
                       filterId: int = None, 
                       products: List[str] = None) -> None:
        """ 
            Inits ActualQueryParameters 
        
            Args:

                ids: An int that sets list of marketdata ID's to be queried
                extractionRangeConfig: Sets the extraction range configuration.
                extraxtionRangeType: Sets the extraction range type.
                timezone: IANA Format. A string specifies the timezone of extracted marketdata.
                filterId: An int that filters marketdata ID to be queries.
                products: A string that sets products to be queried.
        """
        _QueryParameters.__init__(self, ids, extractionRangeConfig, extractionRangeType, timezone, filterId)
        self.products = products

==> artesian-sdk-3.0.8.tar.gz: artesian-sdk-3.0.8/Artesian/Query/_QueryParameters/MasQueryParameters.py <==
from typing import List, Optional
from .ExtractionRangeConfig import ExtractionRangeConfig
from .QueryParameters import _QueryParameters
from .ExtractionRangeType import ExtractionRangeType

class MasQueryParameters(_QueryParameters): 
    """ 
        Class for the Mas Query Parameters.

        Attributes:
            ids: sets list of marketdata ID's to be queried
            extractionRangeConfig: Sets the extraction range configuration.
            extraxtionRangeType: Sets the extraction range type.
            timezone: specifies the timezone of extracted marketdata.
            filterId: filters marketdata ID to be queries.
            products: sets products to be queried.
    """
    def __init__(self, ids: Optional[List[int]] = None, 
                       extractionRangeConfig: ExtractionRangeConfig = ExtractionRangeConfig(), 
                       extractionRangeType: Optional[ExtractionRangeType] = None, 
                       timezone: Optional[str] = None, 
                       filterId: Optional[int] = None, 
                       products: Optional[List[str]] = None) -> None:
        """ 
            Inits ActualQueryParameters 
        
            Args:

                ids: An int that sets list of marketdata ID's to be queried
                extractionRangeConfig: Sets the extraction range configuration.
                extraxtionRangeType: Sets the extraction range type.
                timezone: IANA Format. A string specifies the timezone of extracted marketdata.
                filterId: An int that filters marketdata ID to be queries.
                products: A string that sets products to be queried.
        """
        _QueryParameters.__init__(self, ids, extractionRangeConfig, extractionRangeType, timezone, filterId)
        self.products = products
